==> jc-1.4.0.tar.gz: javax/print/PrintException.h <==
// public class javax.print.PrintException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 79eacd5dbabe9403 javax_print_PrintException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_print_PrintException_H_
#define _JC_javax_print_PrintException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_PrintException$sub_refs	_jc_javax_print_PrintException$sub_refs;
typedef struct _jc_javax_print_PrintException$sub_nonrefs	_jc_javax_print_PrintException$sub_nonrefs;
typedef struct _jc_javax_print_PrintException$refs	_jc_javax_print_PrintException$refs;
typedef struct _jc_javax_print_PrintException$nonrefs	_jc_javax_print_PrintException$nonrefs;
typedef struct _jc_javax_print_PrintException$object	_jc_javax_print_PrintException$object;

typedef const struct _jc_javax_print_PrintException$vmethods	_jc_javax_print_PrintException$vmethods;
typedef const struct _jc_javax_print_PrintException$vtable	_jc_javax_print_PrintException$vtable;
typedef const struct _jc_javax_print_PrintException$vtype	_jc_javax_print_PrintException$vtype;

// Constructors
extern void _jc_javax_print_PrintException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_PrintException$object *);
extern void _jc_javax_print_PrintException$method$_init$34e2c2e16bd56612(_jc_env *, struct _jc_javax_print_PrintException$object *, struct _jc_java_lang_Exception$object *);
extern void _jc_javax_print_PrintException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_print_PrintException$object *, struct _jc_java_lang_String$object *);
extern void _jc_javax_print_PrintException$method$_init$d27a3a3f2a4ade11(_jc_env *, struct _jc_javax_print_PrintException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *);

// Virtual methods structure
struct _jc_javax_print_PrintException$vmethods {
};

// Vtable
struct _jc_javax_print_PrintException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_print_PrintException$vmethods	javax_print_PrintException;
};

// Vtype
struct _jc_javax_print_PrintException$vtype {
	_jc_type			type;
	_jc_javax_print_PrintException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_PrintException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_PrintException$refs {
    _jc_javax_print_PrintException$sub_refs	javax_print_PrintException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_PrintException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_PrintException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_print_PrintException$sub_nonrefs	javax_print_PrintException;
};

// Object instance structure
struct _jc_javax_print_PrintException$object {
	_jc_javax_print_PrintException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_PrintException$vtype	*vtype;
	_jc_javax_print_PrintException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_PrintException$vtype _jc_javax_print_PrintException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_PrintException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_PrintException$class_object;

#endif	/* _JC_javax_print_PrintException_H_ */

==> jc-1.4.6.tar.gz: javax/print/PrintException.h <==
// public class javax.print.PrintException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 79eacd5dbabe9403 javax_print_PrintException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_javax_print_PrintException_H_
#define _JC_javax_print_PrintException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_javax_print_PrintException$sub_refs	_jc_javax_print_PrintException$sub_refs;
typedef struct _jc_javax_print_PrintException$sub_nonrefs	_jc_javax_print_PrintException$sub_nonrefs;
typedef struct _jc_javax_print_PrintException$refs	_jc_javax_print_PrintException$refs;
typedef struct _jc_javax_print_PrintException$nonrefs	_jc_javax_print_PrintException$nonrefs;
typedef struct _jc_javax_print_PrintException$object	_jc_javax_print_PrintException$object;

typedef const struct _jc_javax_print_PrintException$vmethods	_jc_javax_print_PrintException$vmethods;
typedef const struct _jc_javax_print_PrintException$vtable	_jc_javax_print_PrintException$vtable;
typedef const struct _jc_javax_print_PrintException$vtype	_jc_javax_print_PrintException$vtype;

// Constructors
extern void _jc_javax_print_PrintException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_print_PrintException$object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_PrintException$method$_init$34e2c2e16bd56612(_jc_env *, struct _jc_javax_print_PrintException$object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_PrintException$method$_init$c31b894660454d13(_jc_env *, struct _jc_javax_print_PrintException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_javax_print_PrintException$method$_init$d27a3a3f2a4ade11(_jc_env *, struct _jc_javax_print_PrintException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_javax_print_PrintException$vmethods {
};

// Vtable
struct _jc_javax_print_PrintException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_javax_print_PrintException$vmethods	javax_print_PrintException;
};

// Vtype
struct _jc_javax_print_PrintException$vtype {
	_jc_type			type;
	_jc_javax_print_PrintException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_print_PrintException$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_print_PrintException$refs {
    _jc_javax_print_PrintException$sub_refs	javax_print_PrintException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_print_PrintException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_print_PrintException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_javax_print_PrintException$sub_nonrefs	javax_print_PrintException;
};

// Object instance structure
struct _jc_javax_print_PrintException$object {
	_jc_javax_print_PrintException$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_print_PrintException$vtype	*vtype;
	_jc_javax_print_PrintException$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_print_PrintException$vtype _jc_javax_print_PrintException$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_print_PrintException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_print_PrintException$class_object;

#endif	/* _JC_javax_print_PrintException_H_ */
